@@ -11,7 +11,4 @@
 # Define application constants.
 
 APP = "wajig"
-VERSION = "3.0.12"
-
-SIMULATE = False
-TEACH = False
+VERSION = "3.1.0"
